@@ -1,6 +1,6 @@
 package Net::OAuth::LP::Models::Activity;
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 use strictures 1;
 use Moo;
@@ -14,7 +14,7 @@ with('Net::OAuth::LP::Models');
 has 'activity' => (is => 'rw',);
 
 method entries {
-  array(@{$self->activity->{entries}});
+  array(@{$self->activity->entries});
 }
 
 1;
