@@ -1,20 +1,19 @@
 package Net::OAuth::LP::Models::Attachments;
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 use strictures 1;
 use Moo;
 use Types::Standard qw(Str Int ArrayRef HashRef);
 use Method::Signatures;
 use List::Objects::WithUtils;
-use Data::Dump qw(pp);
 
 with('Net::OAuth::LP::Models');
 
 has 'attachments' => (is => 'rw',);
 
 method entries {
-  array(@{$self->attachments->{entries}});
+  array(@{$self->attachments->entries});
 }
 
 1;
