@@ -1,6 +1,6 @@
 package Net::OAuth::LP::Models::Messages;
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 use strictures 1;
 use Moo;
@@ -14,7 +14,7 @@ with('Net::OAuth::LP::Models');
 has 'messages' => (is => 'rw',);
 
 method entries {
-  array(@{$self->messages->{entries}});
+  array(@{$self->messages->entries});
 }
 
 1;
@@ -41,14 +41,10 @@ Interface to setting/retrieving bug messages information
 
 =head1 METHODS
 
+In addition to those listed this object inherits methods from List::Objects::WithUtils.
+
 =head2 B<new>
 
     my $messages = Net::OAuth::LP::Models::Messages->new(messages => $bug->messages);
 
-=head2 B<all>
-
-Returns all messages results
-
-    say $messages->all;
-
 =cut
