@@ -1,12 +1,13 @@
 package Net::OAuth::LP::Models::Watches;
 
-# VERSION
+our $VERSION = '0.012'; # VERSION
 
 use strictures 1;
 use Moo;
 use Types::Standard qw(Str Int ArrayRef HashRef);
 use Method::Signatures;
 use List::Objects::WithUtils;
+use Data::Dump qw(pp);
 
 with('Net::OAuth::LP::Models');
 
@@ -38,10 +39,6 @@ Interface to setting/retrieving bug watches information
     $b->find(1);
     say $b->watches->all;
 
-=head1 ATTRIBUTES
-
-=head2 B<watches>
-
 =head1 METHODS
 
 In addition to those listed this object inherits methods from List::Objects::WithUtils.
